Crate ax_runtime

Crate ax_runtime 

Runtime library of ArceOS.

Any application uses ArceOS should link this library. It does some initialization work before entering the application’s main function.

Cargo Features

  • paging: Enable page table manipulation support.
  • smp: Enable SMP (symmetric multiprocessing) support.
  • fs: Enable filesystem support.
  • net: Enable networking support.
  • display: Enable graphics support.

Interrupt handling and multi-task scheduling are mandatory runtime capabilities. The listed features are optional and disabled by default.

Re-exports

pub use ax_hal as hal;

Modules

console
Sleepable task-context access to the runtime-owned physical console.
emergency_console
Synchronous emergency text output.
irq
serial
UART runtime ownership and task-context data service.
sync
Native ArceOS lock facade and ax-sync bridge provider.

Enums

RuntimeError
Errors owned by the ArceOS runtime layer.

Functions

rust_main
The main entry point of the ArceOS runtime.
terminate
Drains task-console output before shutting down the whole system.

Type Aliases

RuntimeResult
A result returned by an ArceOS runtime-owned operation.

Attribute Macros

ax_app_entry