pub fn is_active(runtime: &SerialRuntimeHandle) -> boolExpand description
Returns whether this runtime owns the active physical console.
pub fn is_active(runtime: &SerialRuntimeHandle) -> boolReturns whether this runtime owns the active physical console.