pub fn take_input() -> RuntimeResult<TaskConsoleInput>Expand description
Takes the unique raw input capability for the active console.
pub fn take_input() -> RuntimeResult<TaskConsoleInput>Takes the unique raw input capability for the active console.