Module sync

Module sync 

Native ArceOS lock facade and ax-sync bridge provider.

Structs

IrqSaveGuard
An RAII guard which saves and disables local interrupts while it is alive.
PreemptGuard
An RAII guard which disables kernel preemption while it is alive.
PreemptIrqSaveGuard
An RAII guard which disables preemption and local interrupts.
RawIrqSaveMutex
A raw spin lock that disables kernel preemption and local IRQs while held, mirroring SpinLock::lock_irqsave but exposed as a lock_api::RawMutex for use with foreign generic code.
SpinLock
A non-sleeping mutual-exclusion lock.
SpinRwLock
A non-sleeping read-write lock with acquisition-site context policy.

Functions

dump_lockdep_trace
No-op trace dump for builds without lockdep.
set_lockdep_trace_enabled
No-op trace switch for builds without lockdep.

Type Aliases

RawSpinLockGuard
A guard returned by SpinLock::lock_raw.
RawSpinRwLockReadGuard
A raw read guard.
RawSpinRwLockWriteGuard
A raw write guard.
SpinLockGuard
A guard returned by SpinLock::lock.
SpinLockIrqSaveGuard
A guard returned by SpinLock::lock_irqsave.
SpinRwLockIrqSaveReadGuard
An IRQ-save read guard.
SpinRwLockIrqSaveWriteGuard
An IRQ-save write guard.
SpinRwLockReadGuard
A read guard returned by SpinRwLock::read.
SpinRwLockWriteGuard
A write guard returned by SpinRwLock::write.