pub unsafe fn prepare_user_thread(
builder: ThreadBuilder,
entry: impl FnOnce() + Send + 'static,
options: UserContextOptions,
) -> Result<PreparedThread, TaskError>Expand description
Prepares user architecture resources without publishing or activating the task.
Safety
entry must enter user mode only with the supplied address-space ownership and
initialized architecture state. Inherited FP state must belong to the caller.