pub trait SchedulerAddressSpaceOwner: Send + Sync {
// Required methods
fn release_after_root_switch(
self: Arc<Self>,
proof: AddressSpaceSwitchProof,
);
fn cancel_before_install(self: Arc<Self>, cpu: usize);
fn abandon(self: Arc<Self>, cpu: usize);
}Expand description
Preallocated MM accounting retained by one CPU activation.
These callbacks run with IRQs disabled. They must not allocate, sleep, or destroy the last lifetime anchor for the page tables or their backing store.
Required Methods
Sourcefn release_after_root_switch(self: Arc<Self>, proof: AddressSpaceSwitchProof)
fn release_after_root_switch(self: Arc<Self>, proof: AddressSpaceSwitchProof)
Releases accounting after the runtime completed a hardware root switch.
Sourcefn cancel_before_install(self: Arc<Self>, cpu: usize)
fn cancel_before_install(self: Arc<Self>, cpu: usize)
Cancels a reservation which the runtime never installed in hardware.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".